==> usgs_shakecast-4.0.9-py2-none-any.whl: shakecast/web_src/src/app/shared/maps/layers/epicenter.ts <==
import * as L from 'leaflet';
import { Layer } from './layer';

const epicIcon = L.icon({
    iconUrl: 'assets/epicenter.png',
    iconSize:     [40, 40], // size of the icon
    iconAnchor:   [20, 20], // point of the icon which will correspond to marker's location
    popupAnchor:  [0, 0] // point from which the popup should open relative to the iconAnchor
});

function createEventMarker(event: any) {
    const marker: any = L.marker([event.lat, event.lon], {icon: epicIcon});

    const popup = `<table class="my-table">
                            <tr>
                                <th>ID:</th>
                                <td>` + event.event_id + `</td>
                            </tr>
                            <tr> 
                                <th>Magnitude:</th>
                                <td>` + event.magnitude + `</td>
                            </tr>
                            <tr>
                                <th>Depth:</th>
                                <td>` + event.depth + `</td>
                            </tr>
                            <tr>
                                <th>Latitude:</th>
                                <td>` + event.lat + `</td>
                            </tr>
                            <tr>
                                <th>Longitude:</th>
                                <td>` + event.lon + `</td>
                            </tr>
                            <tr>
                                <th>Description:</th>
                                <td>` + event.place + `</td>
                            </tr>
                        </table>`;

    marker.bindPopup(popup);

    return marker;
}

function layerGenerator(event, product = null) {
        return createEventMarker(event);
}

const epiLayer = new Layer('Epicenter',
                            'epicenter',
                            layerGenerator);

epiLayer.legendImages = ['assets/legend-epicenter.png'];

export const epicenterLayer = epiLayer;

==> usgs_shakecast-4.1.2-py2-none-any.whl: shakecast/web_src/src/app/shared/maps/layers/epicenter.ts <==
import * as L from 'leaflet';
import { Layer } from './layer';

const epicIcon = L.icon({
    iconUrl: 'assets/epicenter.png',
    iconSize:     [40, 40], // size of the icon
    iconAnchor:   [20, 20], // point of the icon which will correspond to marker's location
    popupAnchor:  [0, 0] // point from which the popup should open relative to the iconAnchor
});

function createEventMarker(event: any) {
    const props = event.properties;
    const marker: any = L.marker([props.lat, props.lon], {icon: epicIcon});

    const popup = `<table class="my-table">
                            <tr>
                                <th>ID:</th>
                                <td>` + props.event_id + `</td>
                            </tr>
                            <tr> 
                                <th>Magnitude:</th>
                                <td>` + props.magnitude + `</td>
                            </tr>
                            <tr>
                                <th>Depth:</th>
                                <td>` + props.depth + `</td>
                            </tr>
                            <tr>
                                <th>Latitude:</th>
                                <td>` + props.lat + `</td>
                            </tr>
                            <tr>
                                <th>Longitude:</th>
                                <td>` + props.lon + `</td>
                            </tr>
                            <tr>
                                <th>Description:</th>
                                <td>` + props.place + `</td>
                            </tr>
                        </table>`;

    marker.bindPopup(popup);

    return marker;
}

function layerGenerator(event, product = null) {
        return createEventMarker(event);
}

const epiLayer = new Layer('Epicenter',
                            'epicenter',
                            layerGenerator);

epiLayer.legendImages = ['assets/legend-epicenter.png'];

export const epicenterLayer = epiLayer;
